@@ -10,7 +10,7 @@ import warnings
 import numpy as np
 import scipy.optimize as optimize
 
-import opentiva.pkpd as pkpd
+from . import pkpd
 
 
 class Pump:
